ECS — boto v2.27.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »
- API Reference »

# ECS

## boto.ecs

class `boto.ecs.` `ECSConnection`(aws_access_key_id=None, aws_secret_access_key=None, is_secure=True, port=None, proxy=None, proxy_port=None, proxy_user=None, proxy_pass=None, host='ecs.amazonaws.com', debug=0, https_connection_factory=None, path='/', security_token=None, profile_name=None)

  ECommerce Connection

  For more information on how to use this module see:

  http://blog.coredumped.org/2010/09/search-for-books-on-amazon-using-boto.html

  `APIVersion` = '2010-11-01'
  `get_response`(action, params, page=0, itemSet=None)

    Utility method to handle calls to ECS and parsing of responses.

  `item_lookup`(**params)

    Returns items that satisfy the lookup query.

    For a full list of parameters, see: http://s3.amazonaws.com/awsdocs/Associates/2011-08-01/prod-adv-api-dg-2011-08-01.pdf

  `item_search`(search_index, **params)

    Returns items that satisfy the search criteria, including one or more search indices.

    For a full list of search terms, :see: http://docs.amazonwebservices.com/AWSECommerceService/2010-09-01/DG/index.html?ItemSearch.html

## boto.ecs.item

class `boto.ecs.item.` `Item`(connection=None)

  A single Item

  Initialize this Item

class `boto.ecs.item.` `ItemSet`(connection, action, params, page=0)

  A special ResponseGroup that has built-in paging, and only creates new Items on the “Item” tag

  `endElement`(name, value, connection)
  `next`()

    Special paging functionality

  `startElement`(name, attrs, connection)
  `to_xml`()

    Override to first fetch everything

class `boto.ecs.item.` `ResponseGroup`(connection=None, nodename=None)

  A Generic “Response Group”, which can be anything from the entire list of Items to specific response elements within an item

  Initialize this Item

  `endElement`(name, value, connection)
  `get`(name)
  `set`(name, value)
  `startElement`(name, attrs, connection)
  `to_xml`()

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »
- API Reference »